pub struct FirmwareVersion;Trait Implementations
Sourceimpl Archive for FirmwareVersion
impl Archive for FirmwareVersion
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFirmwareVersion
type Archived = ArchivedFirmwareVersion
The archived representation of this type. Read more
Sourcetype Resolver = FirmwareVersionResolver
type Resolver = FirmwareVersionResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for FirmwareVersion
impl BlockingArchive for FirmwareVersion
Sourceimpl Debug for FirmwareVersion
impl Debug for FirmwareVersion
Sourceimpl<__D: Fallible + ?Sized> Deserialize<FirmwareVersion, __D> for Archived<FirmwareVersion>
impl<__D: Fallible + ?Sized> Deserialize<FirmwareVersion, __D> for Archived<FirmwareVersion>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FirmwareVersion, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FirmwareVersion, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for FirmwareVersion
impl MessageId for FirmwareVersion