pub struct GetUpdateStatus;Trait Implementations
Sourceimpl Archive for GetUpdateStatus
impl Archive for GetUpdateStatus
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetUpdateStatus
type Archived = ArchivedGetUpdateStatus
The archived representation of this type. Read more
Sourcetype Resolver = GetUpdateStatusResolver
type Resolver = GetUpdateStatusResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetUpdateStatus
impl BlockingArchive for GetUpdateStatus
Sourcetype Response = UpdateStatus
type Response = UpdateStatus
response type for this message
Sourceimpl Debug for GetUpdateStatus
impl Debug for GetUpdateStatus
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetUpdateStatus, __D> for Archived<GetUpdateStatus>
impl<__D: Fallible + ?Sized> Deserialize<GetUpdateStatus, __D> for Archived<GetUpdateStatus>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetUpdateStatus, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetUpdateStatus, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetUpdateStatus
impl MessageId for GetUpdateStatus