pub struct SubscribeUpdateProgress;Trait Implementations
Sourceimpl Archive for SubscribeUpdateProgress
impl Archive for SubscribeUpdateProgress
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSubscribeUpdateProgress
type Archived = ArchivedSubscribeUpdateProgress
The archived representation of this type. Read more
Sourcetype Resolver = SubscribeUpdateProgressResolver
type Resolver = SubscribeUpdateProgressResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl ArchiveSubscription for SubscribeUpdateProgress
impl ArchiveSubscription for SubscribeUpdateProgress
Sourceimpl Debug for SubscribeUpdateProgress
impl Debug for SubscribeUpdateProgress
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SubscribeUpdateProgress, __D> for Archived<SubscribeUpdateProgress>
impl<__D: Fallible + ?Sized> Deserialize<SubscribeUpdateProgress, __D> for Archived<SubscribeUpdateProgress>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SubscribeUpdateProgress, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SubscribeUpdateProgress, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SubscribeUpdateProgress
impl MessageId for SubscribeUpdateProgress