pub struct UpdateStatus {
pub downloaded_update: bool,
pub needs_continue: bool,
pub installing: bool,
pub sufficient_battery: bool,
}Expand description
Status of the update system, used to determine if an update can be applied.
Fields
downloaded_update: boolWhether there is a downloaded update ready to apply.
needs_continue: boolWhether there is an update that was interrupted by reboot and needs to continue.
installing: boolWhether a firmware update is currently being installed.
sufficient_battery: boolWhether the battery level is sufficient for an update.